@@ -19,7 +19,7 @@
  */
 
 /**
- * SECTION:gstqml6gmixer
+ * SECTION:element-qml6glmixer
  *
  * `qml6glmixer` provides a way to render an almost-arbitrary QML scene within
  * GStreamer pipeline using the same OpenGL context that GStreamer uses
@@ -72,6 +72,8 @@
  *
  * The Qml scene will run at configured output framerate.  The timestamps on the
  * output buffers are used to drive the animation time.
+ *
+ * Since: 1.24
  */
 
 #ifdef HAVE_CONFIG_H
@@ -122,7 +124,9 @@ gst_qml6_gl_mixer_pad_prepare_frame (GstVideoAggregatorPad *vagg_pad, GstVideoAg
     GstGLContext *context;
 
     in_caps = gst_video_info_to_caps (&vagg_pad->info);
-    gst_caps_set_features_simple (in_caps, gst_caps_features_from_string (GST_CAPS_FEATURE_MEMORY_GL_MEMORY));
+    gst_caps_set_features_simple (in_caps,
+        gst_caps_features_new_single_static_str
+        (GST_CAPS_FEATURE_MEMORY_GL_MEMORY));
     pad->widget->setCaps (in_caps);
     gst_clear_caps (&in_caps);
 
@@ -315,7 +319,7 @@ gst_qml6_gl_mixer_class_init (GstQml6GLMixerClass * klass)
   gobject_class->get_property = gst_qml6_gl_mixer_get_property;
   gobject_class->finalize = gst_qml6_gl_mixer_finalize;
 
-  gst_element_class_set_metadata (gstelement_class, "Qt6 Video Mixer",
+  gst_element_class_set_static_metadata (gstelement_class, "Qt6 Video Mixer",
       "Video/QML/Mixer", "A mixer that renders a QML scene",
       "Matthew Waters <matthew@centricular.com>");
 
@@ -361,6 +365,8 @@ gst_qml6_gl_mixer_class_init (GstQml6GLMixerClass * klass)
       &src_factory, GST_TYPE_AGGREGATOR_PAD);
   gst_element_class_add_static_pad_template_with_gtype (element_class,
       &sink_factory, GST_TYPE_QML6_GL_MIXER_PAD);
+
+  gst_type_mark_as_plugin_api (GST_TYPE_QML6_GL_MIXER_PAD, (GstPluginAPIFlags) 0);
 }
 
 static void
@@ -585,8 +591,8 @@ gst_qml6_gl_mixer_change_state (GstElement * element,
   GstStateChangeReturn ret = GST_STATE_CHANGE_SUCCESS;
 
   GST_DEBUG_OBJECT (element, "changing state: %s => %s",
-      gst_element_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
-      gst_element_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
+      gst_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
+      gst_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
 
   switch (transition) {
     case GST_STATE_CHANGE_NULL_TO_READY: {
