@@ -42,6 +42,7 @@
 
 #include <string.h>
 
+#include "gstaudioparserselements.h"
 #include "gstamrparse.h"
 #include <gst/pbutils/pbutils.h>
 
@@ -85,6 +86,8 @@ static GstFlowReturn gst_amr_parse_pre_push_frame (GstBaseParse * parse,
     GstBaseParseFrame * frame);
 
 G_DEFINE_TYPE (GstAmrParse, gst_amr_parse, GST_TYPE_BASE_PARSE);
+GST_ELEMENT_REGISTER_DEFINE (amrparse, "amrparse",
+    GST_RANK_PRIMARY + 1, GST_TYPE_AMR_PARSE);
 
 /**
  * gst_amr_parse_class_init:
@@ -260,7 +263,6 @@ gst_amr_parse_handle_frame (GstBaseParse * parse,
   GstMapInfo map;
   gint fsize = 0, mode, dsize;
   GstAmrParse *amrparse;
-  GstFlowReturn ret = GST_FLOW_OK;
   gboolean found = FALSE;
 
   amrparse = GST_AMR_PARSE (parse);
@@ -310,18 +312,21 @@ gst_amr_parse_handle_frame (GstBaseParse * parse,
       } else if (GST_BASE_PARSE_DRAINING (parse)) {
         /* not enough, but draining, so ok */
         found = TRUE;
+        fsize = map.size;
       }
     }
   }
 
+  found = found && fsize <= map.size;
+
 done:
   gst_buffer_unmap (buffer, &map);
 
-  if (found && fsize <= map.size) {
-    ret = gst_base_parse_finish_frame (parse, frame, fsize);
+  if (found) {
+    return gst_base_parse_finish_frame (parse, frame, fsize);
   }
 
-  return ret;
+  return GST_FLOW_OK;
 }
 
 /**
