@@ -737,6 +737,8 @@ typedef struct _AtomTRAK
   /* some helper info for structural conformity checks */
   gboolean is_video;
   gboolean is_h264;
+  gboolean is_ac3;
+  gboolean is_eac3;
 
   AtomsContext *context;
 } AtomTRAK;
@@ -930,6 +932,21 @@ struct _AtomInfo
   AtomFreeFunc free_func;
 };
 
+typedef struct _EAC3BitstreamInfo
+{
+  guint8 strmtyp;
+  guint8 substreamid;
+  guint16 frmsiz;
+  guint8 fscod;
+  guint8 numblkscod;
+  guint8 acmod;
+  guint8 lfeon;
+  guint8 bsid;
+  guint8 bsmod;
+  guint16 chanmap;
+
+} EAC3BitstreamInfo;
+
 guint64    atoms_get_current_qt_time   (void);
 
 guint64    atom_copy_data              (Atom *atom, guint8 **buffer,
@@ -967,6 +984,7 @@ void       atom_moov_set_fragmented    (AtomMOOV *moov, gboolean fragmented);
 void       atom_moov_chunks_set_offset (AtomMOOV *moov, guint32 offset);
 void       atom_moov_add_trak          (AtomMOOV *moov, AtomTRAK *trak);
 guint      atom_moov_get_trak_count    (AtomMOOV *moov);
+guint64    atom_moov_calc_stco_to_co64_conversion_total_offset (AtomMOOV *moov, guint64 offset);
 
 guint      atom_framerate_to_timescale (gint fps_n, gint fps_d);
 
@@ -1106,6 +1124,7 @@ AtomInfo *   build_tapt_extension        (gint clef_width, gint clef_height, gin
 AtomInfo *   build_ac3_extension         (guint8 fscod, guint8 bsid,
                                           guint8 bsmod, guint8 acmod,
                                           guint8 lfe_on, guint8 bitrate_code);
+AtomInfo *   build_eac3_extension        (GArray *bitstreamInfo);
 AtomInfo *   build_opus_extension        (guint32 rate, guint8 channels, guint8 mapping_family,
                                           guint8 stream_count, guint8 coupled_count,
                                           guint8 channel_mapping[256], guint16 pre_skip,
@@ -1118,6 +1137,11 @@ AtomInfo *   build_SMI_atom              (const GstBuffer *seqh);
 AtomInfo *   build_ima_adpcm_extension   (gint channels, gint rate,
                                           gint blocksize);
 AtomInfo *   build_uuid_xmp_atom         (GstBuffer * xmp);
+AtomInfo *   build_vpcC_extension        (guint8 profile, guint8 level, guint8 bit_depth,
+                                          guint8 chroma_subsampling, gboolean video_full_range,
+                                          guint8 colour_primaries, guint8 transfer_characteristics,
+                                          guint8 matrix_coefficients);
+AtomInfo *   build_vvcC_extension        (guint8 version, guint32 flags, const GstBuffer* codec_data);
 
 
 /*
