@@ -26,14 +26,18 @@
  * @see_also: #GstRgLimiter, #GstRgAnalysis
  *
  * This element applies volume changes to streams as lined out in the proposed
- * [ReplayGain standard](https://wiki.hydrogenaud.io/index.php?title=ReplayGain).
- * It interprets the ReplayGain meta data tags and carries out the adjustment
- * (by using a volume element internally).
+ * [ReplayGain standard](https://wiki.hydrogenaud.io/index.php?title=ReplayGain)
+ * and in the [EBU R 128](https://tech.ebu.ch/publications/r128/) standard.
+ * It interprets the ReplayGain and R128 meta data tags and carries out the
+ * adjustment (by using a volume element internally).
+ * If R128 tags are present, ReplayGain tags are ignored.
  *
  * The relevant tags are:
  * * #GST_TAG_TRACK_GAIN
+ * * #GST_TAG_TRACK_GAIN_R128
  * * #GST_TAG_TRACK_PEAK
  * * #GST_TAG_ALBUM_GAIN
+ * * #GST_TAG_ALBUM_GAIN_R128
  * * #GST_TAG_ALBUM_PEAK
  * * #GST_TAG_REFERENCE_LEVEL
  *
@@ -118,6 +122,8 @@ static GstStaticPadTemplate src_template = GST_STATIC_PAD_TEMPLATE ("src",
 
 #define gst_rg_volume_parent_class parent_class
 G_DEFINE_TYPE (GstRgVolume, gst_rg_volume, GST_TYPE_BIN);
+GST_ELEMENT_REGISTER_DEFINE (rgvolume, "rgvolume", GST_RANK_NONE,
+    GST_TYPE_RG_VOLUME);
 
 static void gst_rg_volume_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -477,7 +483,9 @@ gst_rg_volume_tag_event (GstRgVolume * self, GstEvent * event)
 {
   GstTagList *tag_list;
   gboolean has_track_gain, has_track_peak, has_album_gain, has_album_peak;
+  gboolean has_track_gain_r128, has_album_gain_r128;
   gboolean has_ref_level;
+  gdouble track_gain_r128, album_gain_r128;
 
   g_return_val_if_fail (event != NULL, NULL);
   g_return_val_if_fail (GST_EVENT_TYPE (event) == GST_EVENT_TAG, event);
@@ -489,16 +497,21 @@ gst_rg_volume_tag_event (GstRgVolume * self, GstEvent * event)
 
   has_track_gain = gst_tag_list_get_double (tag_list, GST_TAG_TRACK_GAIN,
       &self->track_gain);
+  has_track_gain_r128 = gst_tag_list_get_double (tag_list,
+      GST_TAG_TRACK_GAIN_R128, &track_gain_r128);
   has_track_peak = gst_tag_list_get_double (tag_list, GST_TAG_TRACK_PEAK,
       &self->track_peak);
   has_album_gain = gst_tag_list_get_double (tag_list, GST_TAG_ALBUM_GAIN,
       &self->album_gain);
+  has_album_gain_r128 = gst_tag_list_get_double (tag_list,
+      GST_TAG_ALBUM_GAIN_R128, &album_gain_r128);
   has_album_peak = gst_tag_list_get_double (tag_list, GST_TAG_ALBUM_PEAK,
       &self->album_peak);
   has_ref_level = gst_tag_list_get_double (tag_list, GST_TAG_REFERENCE_LEVEL,
       &self->reference_level);
 
-  if (!has_track_gain && !has_track_peak && !has_album_gain && !has_album_peak)
+  if (!has_track_gain && !has_track_gain_r128 && !has_track_peak &&
+      !has_album_gain && !has_album_gain_r128 && !has_album_peak)
     return event;
 
   if (has_ref_level && (has_track_gain || has_album_gain)
@@ -515,6 +528,25 @@ gst_rg_volume_tag_event (GstRgVolume * self, GstEvent * event)
     self->album_gain += RG_REFERENCE_LEVEL - self->reference_level;
   }
 
+  /*
+   * R128 tags can be present together with RG tags, should take priority,
+   * and should not take interference from RG reference level or peak tags.
+   */
+  if (has_track_gain_r128) {
+    has_track_peak = FALSE;
+    self->track_gain = track_gain_r128 + 5.;
+    GST_DEBUG_OBJECT (self,
+        "decoded R128 track gain %lf as %" GAIN_FORMAT,
+        track_gain_r128, self->track_gain);
+  }
+  if (has_album_gain_r128) {
+    has_album_peak = FALSE;
+    self->album_gain = album_gain_r128 + 5.;
+    GST_DEBUG_OBJECT (self,
+        "decoded R128 album gain %lf as %" GAIN_FORMAT,
+        album_gain_r128, self->album_gain);
+  }
+
   /* Ignore values that are obviously invalid. */
   if (G_UNLIKELY (has_track_gain && !VALID_GAIN (self->track_gain))) {
     GST_DEBUG_OBJECT (self,
@@ -551,15 +583,17 @@ gst_rg_volume_tag_event (GstRgVolume * self, GstEvent * event)
     self->album_peak = 1.0;
   }
 
-  self->has_track_gain |= has_track_gain;
+  self->has_track_gain |= has_track_gain | has_track_gain_r128;
   self->has_track_peak |= has_track_peak;
-  self->has_album_gain |= has_album_gain;
+  self->has_album_gain |= has_album_gain | has_album_gain_r128;
   self->has_album_peak |= has_album_peak;
 
   tag_list = gst_tag_list_copy (tag_list);
   gst_tag_list_remove_tag (tag_list, GST_TAG_TRACK_GAIN);
+  gst_tag_list_remove_tag (tag_list, GST_TAG_TRACK_GAIN_R128);
   gst_tag_list_remove_tag (tag_list, GST_TAG_TRACK_PEAK);
   gst_tag_list_remove_tag (tag_list, GST_TAG_ALBUM_GAIN);
+  gst_tag_list_remove_tag (tag_list, GST_TAG_ALBUM_GAIN_R128);
   gst_tag_list_remove_tag (tag_list, GST_TAG_ALBUM_PEAK);
   gst_tag_list_remove_tag (tag_list, GST_TAG_REFERENCE_LEVEL);
 
